==> ngx-super-table-0.0.1.tgz: package/superTable.component.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, ElementRef, Input } from '@angular/core';
import { SuperTableState } from './SuperTableState';
var SuperTable = (function () {
    function SuperTable(el, state) {
        this.el = el;
        this.state = state;
        // properties
        this.isReady = false;
        this.hasError = false;
    }
    SuperTable.prototype.ngOnInit = function () {
        var _this = this;
        this.subscription = this.state.stateChanged$.subscribe(function () { return _this.sortAndFilterRows(); });
    };
    SuperTable.prototype.ngAfterContentInit = function () {
        if (this.options.autoHeight) {
            var parentHeight = this.el.nativeElement.parentElement.clientHeight;
            this.setTableHeight(parentHeight);
        }
        this.isReady = true;
    };
    SuperTable.prototype.ngOnChanges = function (changes) {
        // Inform state of columns changes
        if (changes['columns'].isFirstChange()) {
            this.state.setColumns(changes['columns'].currentValue);
        }
        this.sortAndFilterRows();
    };
    SuperTable.prototype.ngOnDestroy = function () {
        this.subscription.unsubscribe();
    };
    SuperTable.prototype.setTableHeight = function (totalHeight) {
        // calculate header height
        var headerHeight = this.el.nativeElement.querySelector('super-table-head').offsetHeight;
        // subtract it from totalHeight, set bodyHeight to result
        this.bodyHeight = totalHeight - headerHeight;
    };
    SuperTable.prototype.sortAndFilterRows = function () {
        var _this = this;
        // Filtering
        var activeFilterColumns = this.state.columns.filter(function (c) {
            return !!c.def.filter && !!c.def.filter.isActive(c.filterValue);
        });
        if (activeFilterColumns.length) {
            this.filteredSortedRows = this.rows.filter(function (row) {
                for (var i = 0; i < activeFilterColumns.length; i++) {
                    var colState = activeFilterColumns[i];
                    var val = row[colState.def.key];
                    var filterResult = colState.def.filter.fn(colState.filterValue, val, row);
                    if (filterResult === false) {
                        return false;
                    }
                }
                return true;
            });
        }
        else {
            this.filteredSortedRows = this.rows.slice();
        }
        // Sorting
        this.filteredSortedRows.sort(function (a, b) {
            for (var i = 0; i < _this.state.sortStack.length; i++) {
                var colState = _this.state.sortStack[i];
                var val1 = a[colState.def.key];
                var val2 = b[colState.def.key];
                var compareResult = colState.sortOrder === 'ASC'
                    ? colState.def.sort(val1, val2, a, b)
                    : colState.def.sort(val2, val1, b, a);
                if (compareResult !== 0) {
                    return compareResult;
                }
            }
            return 0;
        });
    };
    return SuperTable;
}());
__decorate([
    Input(),
    __metadata("design:type", Array)
], SuperTable.prototype, "rows", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], SuperTable.prototype, "columns", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], SuperTable.prototype, "options", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], SuperTable.prototype, "tableClasses", void 0);
SuperTable = __decorate([
    Component({
        selector: 'super-table',
        template: "\n    <super-table-head [tableClasses]=\"tableClasses\"></super-table-head>\n\n    <super-table-body\n      *ngIf=\"isReady\"\n      [rows]=\"filteredSortedRows\"\n      [tableClasses]=\"tableClasses\"\n      [options]=\"options\"\n      [style.height]=\"bodyHeight + 'px'\"\n      [bodyHeight]=\"bodyHeight\">\n    </super-table-body>\n\n    <div\n      class=\"loading-message\"\n      *ngIf=\"!isReady && !hasError\">\n      Loading...\n    </div>\n\n    <div *ngIf=\"hasError\">An error occurred.</div>\n  ",
        styles: ["\n    :host {\n      position: relative;\n      display: block;\n    }\n    .loading-message {\n      text-align: center;\n    }\n  "],
        providers: [SuperTableState]
    }),
    __metadata("design:paramtypes", [ElementRef, SuperTableState])
], SuperTable);
export { SuperTable };

==> ngx-super-table-0.0.2.tgz: package/superTable.component.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, ElementRef, Input } from '@angular/core';
import { SuperTableState } from './SuperTableState';
var SuperTable = (function () {
    function SuperTable(el, state) {
        this.el = el;
        this.state = state;
        // properties
        this.isReady = false;
        this.hasError = false;
    }
    SuperTable.prototype.ngOnInit = function () {
        var _this = this;
        this.subscription = this.state.stateChanged$.subscribe(function () { return _this.sortAndFilterRows(); });
    };
    SuperTable.prototype.ngAfterContentInit = function () {
        if (this.options.autoHeight) {
            var parentHeight = this.el.nativeElement.parentElement.clientHeight;
            this.setTableHeight(parentHeight);
        }
        this.isReady = true;
    };
    SuperTable.prototype.ngOnChanges = function (changes) {
        // Inform state of columns changes
        if (changes['columns'] && changes['columns'].isFirstChange()) {
            this.state.setColumns(changes['columns'].currentValue);
        }
        this.sortAndFilterRows();
    };
    SuperTable.prototype.ngOnDestroy = function () {
        this.subscription.unsubscribe();
    };
    SuperTable.prototype.setTableHeight = function (totalHeight) {
        // calculate header height
        var headerHeight = this.el.nativeElement.querySelector('super-table-head').offsetHeight;
        // subtract it from totalHeight, set bodyHeight to result
        this.bodyHeight = totalHeight - headerHeight;
    };
    SuperTable.prototype.sortAndFilterRows = function () {
        var _this = this;
        // Filtering
        var activeFilterColumns = this.state.columns.filter(function (c) {
            return !!c.def.filter && !!c.def.filter.isActive(c.filterValue);
        });
        if (activeFilterColumns.length) {
            this.filteredSortedRows = this.rows.filter(function (row) {
                for (var i = 0; i < activeFilterColumns.length; i++) {
                    var colState = activeFilterColumns[i];
                    var val = row[colState.def.key];
                    var filterResult = colState.def.filter.fn(colState.filterValue, val, row);
                    if (filterResult === false) {
                        return false;
                    }
                }
                return true;
            });
        }
        else {
            this.filteredSortedRows = this.rows.slice();
        }
        // Sorting
        this.filteredSortedRows.sort(function (a, b) {
            for (var i = 0; i < _this.state.sortStack.length; i++) {
                var colState = _this.state.sortStack[i];
                var val1 = a[colState.def.key];
                var val2 = b[colState.def.key];
                var compareResult = colState.sortOrder === 'ASC'
                    ? colState.def.sort(val1, val2, a, b)
                    : colState.def.sort(val2, val1, b, a);
                if (compareResult !== 0) {
                    return compareResult;
                }
            }
            return 0;
        });
    };
    return SuperTable;
}());
__decorate([
    Input(),
    __metadata("design:type", Array)
], SuperTable.prototype, "rows", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], SuperTable.prototype, "columns", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], SuperTable.prototype, "options", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], SuperTable.prototype, "tableClasses", void 0);
SuperTable = __decorate([
    Component({
        selector: 'super-table',
        template: "\n    <super-table-head [tableClasses]=\"tableClasses\"></super-table-head>\n\n    <super-table-body\n      *ngIf=\"isReady\"\n      [rows]=\"filteredSortedRows\"\n      [tableClasses]=\"tableClasses\"\n      [options]=\"options\"\n      [style.height]=\"bodyHeight + 'px'\"\n      [bodyHeight]=\"bodyHeight\">\n    </super-table-body>\n\n    <div\n      class=\"loading-message\"\n      *ngIf=\"!isReady && !hasError\">\n      Loading...\n    </div>\n\n    <div *ngIf=\"hasError\">An error occurred.</div>\n  ",
        styles: ["\n    :host {\n      position: relative;\n      display: block;\n    }\n    .loading-message {\n      text-align: center;\n    }\n  "],
        providers: [SuperTableState]
    }),
    __metadata("design:paramtypes", [ElementRef, SuperTableState])
], SuperTable);
export { SuperTable };
